/* global vrn_frontend_params */

jQuery( function( $ ) {
    'use strict';
    // vrn_frontend_params is required to continue, ensure the object exists
    if ( typeof vrn_frontend_params === 'undefined' ) {
        return false;
    }

    var is_blocked = function( $node ) {
        return $node.is( '.processing' ) || $node.parents( '.processing' ).length;
    };
    /**
     * Block a node visually for processing.
     *
     * @param {JQuery Object} $node
     */
    var block = function( $node ) {
        $.blockUI.defaults.overlayCSS.cursor = 'wait';
        if ( ! is_blocked( $node ) ) {
            $node.addClass( 'processing' ).block( {
                message : null,
                overlayCSS : {
                    background : '#fff',
                    opacity : 0.6
                }
            } );
        }
    };

    /**
     * Unblock a node after processing is complete.
     *
     * @param {JQuery Object} $node
     */
    var unblock = function( $node ) {
        $node.removeClass( 'processing' ).unblock();
    };

    var variation_switcher = {
        init : function() {
            $( document ).on( 'click', '.vrn_variation_toggle', this.toggleSwitcher );
            $( document ).on( 'click', '.vrn_switch_variation', this.switchVariation );
            $( document ).on( 'updated_wc_div', this.refreshVariation );
        },
        toggleSwitcher( evt ) {
            evt.preventDefault();

            //Load wc-variation-form in Checkout Page.
            if ( $( '.woocommerce-checkout' ).length && vrn_frontend_params.enabled_in_checkout ) {
                $( '.variations_form' ).each( function() {
                    $( this ).wc_variation_form();
                } );
            }

            if ( 'modal:open' === $( evt.currentTarget ).attr( 'rel' ) ) {
                $( evt.currentTarget ).closest( 'div' ).find( '.variations_form' ).modal();
            } else {
                $( evt.currentTarget ).closest( 'div' ).find( '.variations_form' ).toggle();
            }
        },
        switchVariation( evt ) {
            evt.preventDefault();

            if ( $( evt.currentTarget ).closest( 'div' ).find( '.variation_id' ).val() > 0 ) {
                $.blockUI.defaults.overlayCSS.cursor = 'wait';
                block( $( '.shop_table' ) );

                $.ajax( {
                    type : 'POST',
                    url : vrn_frontend_params.ajax_url,
                    dataType : 'json',
                    data : {
                        action : '_vrn_switch_variation',
                        security : vrn_frontend_params.switch_variation_nonce,
                        data : $( evt.currentTarget ).closest( 'div' ).find( ':input[name]' ).serialize()
                    },
                    success : function( response ) {
                        $.modal.close();

                        if ( response && false === response.success ) {
                            window.alert( response.data.error );
                        }
                    },
                    complete : function() {
                        if ( $( '.woocommerce-checkout' ).length && vrn_frontend_params.enabled_in_checkout ) {
                            $( document.body ).trigger( 'update_checkout' );
                        } else {
                            $( document.body ).trigger( 'wc_update_cart' );
                        }

                        unblock( $( '.shop_table' ) );
                    }
                } );
            }
        },
        refreshVariation() {
            $( '.variations_form' ).each( function() {
                $( this ).wc_variation_form();
            } );
        },
    };

    variation_switcher.init();
} );
