<?php
defined( 'ABSPATH' ) || exit;

/**
 * Variation Switcher Admin
 * 
 * @class VRN_Admin
 * @package Class
 */
class VRN_Admin {

	/**
	 * Init VRN_Admin.
	 */
	public static function init() {
		add_action( 'init', __CLASS__ . '::includes' );
		add_filter( 'woocommerce_get_settings_pages', __CLASS__ . '::add_settings_page' );
		add_action( 'woocommerce_after_settings_vrn_variation_switcher_in_cart', __CLASS__ . '::add_reset_form' );
		add_action( 'wp_loaded', __CLASS__ . '::reset_settings', 20 );
	}

	/**
	 * Include any classes we need within admin.
	 */
	public static function includes() {
		include_once 'vrn-admin-functions.php';
	}

	/**
	 * Include the settings page.
	 * 
	 * @param array $pages
	 * @return array
	 */
	public static function add_settings_page( $pages ) {
		$pages[] = include 'settings-page/class-vrn-settings-general.php' ;
		return $pages;
	}

	/**
	 * Add settings reset form.
	 */
	public static function add_reset_form() {
		?>
		<form method="post" id="vrn_reset_mainform" action="" enctype="multipart/form-data" style="float: left; margin-top: -52px; margin-left: 159px;">
			<input name="vrn-reset" class="button-secondary" type="submit" value="<?php esc_attr_e( 'Reset', 'variation-switcher-in-cart-for-woocommerce' ); ?>"/>
			<?php wp_nonce_field( 'vrn-reset-settings' ); ?>
		</form>  
		<?php
	}

	/**
	 * Handle reset of settings.
	 */
	public static function reset_settings() {
		if ( empty( $_POST[ 'vrn-reset' ] ) ) {
			return;
		}

		check_admin_referer( 'vrn-reset-settings' );

		$settings = WC_Admin_Settings::get_settings_pages();
		foreach ( $settings as $section ) {
			if ( ! is_callable( array( $section, 'get_settings' ) ) ) {
				continue;
			}

			if ( 'vrn_variation_switcher_in_cart' !== $section->get_id() ) {
				continue;
			}

			foreach ( $section->get_settings() as $value ) {
				if ( isset( $value[ 'id' ], $value[ 'default' ] ) ) {
					$autoload = isset( $value[ 'autoload' ] ) ? ( bool ) $value[ 'autoload' ] : true;

					delete_option( $value[ 'id' ] );
					add_option( $value[ 'id' ], $value[ 'default' ], '', ( $autoload ? 'yes' : 'no' ) );
				}
			}
		}

		/**
		 * Admin options reset.
		 * 
		 * @since 1.0
		 */
		do_action( 'woocommerce_vrn_options_reset' );

		WC_Admin_Settings::add_message( __( 'Your settings have been reset to default values.', 'variation-switcher-in-cart-for-woocommerce' ) );
	}
}

VRN_Admin::init();
