<?php
/**
 * Variation Switcher General Settings
 *
 * @package  
 */
defined( 'ABSPATH' ) || exit;

/**
 * Settings for API.
 */
if ( class_exists( 'VRN_Settings_General', false ) ) {
	return new VRN_Settings_General();
}

/**
 * VRN_Settings_General.
 */
class VRN_Settings_General extends WC_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'vrn_variation_switcher_in_cart';
		$this->label = __( 'Variation Switcher in Cart', 'variation-switcher-in-cart-for-woocommerce' );

		add_action( 'woocommerce_admin_field_vrn_include_products', array( $this, 'get_include_product_selector' ) );
		add_action( 'woocommerce_admin_field_vrn_exclude_products', array( $this, 'get_exclude_product_selector' ) );
		add_action( 'woocommerce_update_options_vrn_variation_switcher_in_cart', array( $this, 'save_custom_fields' ) );

		parent::__construct();
	}

	/**
	 * Get settings array.
	 *
	 * @return array
	 */
	public function get_settings() {
		global $current_section;

		$settings = array(
			array(
				'name' => __( 'General Settings', 'variation-switcher-in-cart-for-woocommerce' ),
				'type' => 'title',
				'id'   => VRN_PREFIX . 'general_settings',
			),
			array(
				'name'     => __( 'Variation Switcher Link for Logged-in Users', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'       => VRN_PREFIX . 'enabled_for_loged_in_users',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => __( 'By enabling this checkbox, you can allow your registered users to change the product variations in the cart.', 'variation-switcher-in-cart-for-woocommerce' ),
			),
			array(
				'name'     => __( 'Variation Switcher Link for Guest Users', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'       => VRN_PREFIX . 'enabled_for_guest_users',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => __( 'By enabling this checkbox, you can allow the guest users to change the product variations in the cart.', 'variation-switcher-in-cart-for-woocommerce' ),
			),
			array(
				'name'     => __( 'Variation Switcher Link in Checkout', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'       => VRN_PREFIX . 'enabled_in_checkout',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => __( 'By enabling this checkbox, you can allow your users to change the product variations in the checkout.', 'variation-switcher-in-cart-for-woocommerce' ),
			),
			array(
				'name'     => __( 'Display Selected Variation', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'       => VRN_PREFIX . 'display_selected_variation',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => __( 'By enabling this checkbox, you can display the selected variation in cart & checkout page selection list.', 'variation-switcher-in-cart-for-woocommerce' ),
			),
			array(
				'name'    => __( 'Variation Switcher Link Display Type', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'display_switcher_as',
				'type'    => 'select',
				'default' => 'list',
				'options' => array(
					'list'  => __( 'List', 'variation-switcher-in-cart-for-woocommerce' ),
					'popup' => __( 'Popup', 'variation-switcher-in-cart-for-woocommerce' ),
				),
			),
			array( 'type' => 'sectionend', 'id' => VRN_PREFIX . 'general_settings' ),
			array(
				'name' => __( 'Localization', 'variation-switcher-in-cart-for-woocommerce' ),
				'type' => 'title',
				'id'   => VRN_PREFIX . 'localization',
			),
			array(
				'name'    => __( 'Change Variation Label ', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'change_variation_label',
				'type'    => 'text',
				'default' => 'Change Variation: ',
			),
			array(
				'name'    => __( 'Variation Change Link Label', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'change_variation_link_label',
				'type'    => 'text',
				'default' => 'Select',
			),
			array(
				'name'    => __( 'Update Variation Button Label ', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'update_variation_label',
				'type'    => 'text',
				'default' => 'Update Variation',
			),
			array(
				'name'    => __( 'Message', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'success_message',
				'type'    => 'text',
				'default' => 'Variation Updated Successfully',
			),
			array( 'type' => 'sectionend', 'id' => VRN_PREFIX . 'localization' ),
			array(
				'name' => __( 'Restriction Settings', 'variation-switcher-in-cart-for-woocommerce' ),
				'type' => 'title',
				'id'   => VRN_PREFIX . 'variation_switcher_restrictions',
			),
			array(
				'name'     => __( 'Product(s)/Category Filter', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'       => VRN_PREFIX . 'get_product_select_type',
				'type'     => 'select',
				'options'  => array(
					'all-products'        => __( 'All Products', 'variation-switcher-in-cart-for-woocommerce' ),
					'included-products'   => __( 'Include Products', 'variation-switcher-in-cart-for-woocommerce' ),
					'excluded-products'   => __( 'Exclude Products', 'variation-switcher-in-cart-for-woocommerce' ),
					'included-categories' => __( 'Include Categories', 'variation-switcher-in-cart-for-woocommerce' ),
					'excluded-categories' => __( 'Exclude Categories', 'variation-switcher-in-cart-for-woocommerce' ),
				),
				'default'  => 'all-products',
				'desc_tip' => __( 'Please search only Variable Product(s) & Variable Subscription(s)', 'variation-switcher-in-cart-for-woocommerce' ),
			),
			array(
				'type' => 'vrn_include_products',
			),
			array(
				'type' => 'vrn_exclude_products',
			),
			array(
				'name'    => __( 'Select included Categories', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'get_included_categories',
				'css'     => 'min-width:350px;',
				'class'   => VRN_PREFIX . 'get_included_categories',
				'newids'  => VRN_PREFIX . 'get_included_categories',
				'type'    => 'multiselect',
				'options' => _vrn_get_category_list(),
			), array(
				'name'    => __( 'Select Excluded Categories', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'get_excluded_categories',
				'css'     => 'min-width:350px;',
				'class'   => VRN_PREFIX . 'get_excluded_categories',
				'newids'  => VRN_PREFIX . 'get_excluded_categories',
				'type'    => 'multiselect',
				'options' => _vrn_get_category_list(),
			),
			array( 'type' => 'sectionend', 'id' => VRN_PREFIX . 'variation_switcher_restrictions' ),
			array(
				'name' => __( 'Custom CSS Settings', 'variation-switcher-in-cart-for-woocommerce' ),
				'type' => 'title',
				'id'   => VRN_PREFIX . 'custom_css',
			),
			array(
				'name'    => __( 'Custom CSS', 'variation-switcher-in-cart-for-woocommerce' ),
				'id'      => VRN_PREFIX . 'inline_style',
				'newids'  => VRN_PREFIX . 'inline_style',
				'type'    => 'textarea',
				'css'     => 'height:200px;',
				'std'     => '',
				'default' => '',
			),
			array( 'type' => 'sectionend', 'id' => VRN_PREFIX . 'custom_css' ),
		);

		/**
		 * Get admin options.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'vrn_get_' . $this->id . '_settings', $settings );
	}

	/**
	 * Custom type field.
	 */
	public function get_include_product_selector() {
		?>
		<tr valign="top">
			<th scope="row" class="titledesc">
				<label for="get_included_products"><?php esc_html_e( 'Include Product(s)', 'variation-switcher-in-cart-for-woocommerce' ); ?></label>
			</th>
			<td class="forminp forminp-select">
				<?php
				_vrn_search_field( array(
					'class'       => 'wc-product-search',
					'id'          => VRN_PREFIX . 'get_included_products',
					'type'        => 'product',
					'action'      => VRN_PREFIX . 'json_search_variable_products',
					'multiple'    => true,
					'placeholder' => __( 'Search for a product&hellip;', 'variation-switcher-in-cart-for-woocommerce' ),
					'options'     => get_option( VRN_PREFIX . 'get_included_products', array() ),
				) );
				?>
			</td>
		</tr>
		<?php
	}

	/**
	 * Custom type field.
	 */
	public function get_exclude_product_selector() {
		?>
		<tr valign="top">
			<th scope="row" class="titledesc">
				<label for="get_excluded_products"><?php esc_html_e( 'Exclude Product(s)', 'variation-switcher-in-cart-for-woocommerce' ); ?></label>
			</th>
			<td class="forminp forminp-select">
				<?php
				_vrn_search_field( array(
					'class'       => 'wc-product-search',
					'id'          => VRN_PREFIX . 'get_excluded_products',
					'type'        => 'product',
					'action'      => VRN_PREFIX . 'json_search_variable_products',
					'multiple'    => true,
					'placeholder' => __( 'Search for a product&hellip;', 'variation-switcher-in-cart-for-woocommerce' ),
					'options'     => get_option( VRN_PREFIX . 'get_excluded_products', array() ),
				) );
				?>
			</td>
		</tr>
		<?php
	}

	/**
	 * Save the custom types.
	 */
	public function save_custom_fields() {
		check_admin_referer( 'woocommerce-settings' );

		$posted   = $_POST;
		$metakeys = array(
			'get_included_products' => 'multisearch',
			'get_excluded_products' => 'multisearch',
		);

		foreach ( $metakeys as $key => $type ) {
			if ( ! isset( $posted[ VRN_PREFIX . "{$key}" ] ) ) {
				continue;
			}

			$posted_value = wc_clean( $posted[ VRN_PREFIX . "{$key}" ] );

			if ( 'multisearch' === $type ) {
				if ( ! is_array( $posted_value ) ) {
					$value = array_filter( array_map( 'absint', explode( ',', $posted_value ) ) );
				} else {
					$value = $posted_value;
				}
			} else {
				$value = $posted_value;
			}

			update_option( VRN_PREFIX . "{$key}", wc_clean( $value ) );
		}
	}
}

return new VRN_Settings_General();
