<?php
/**
 * Our Admin Functions
 */
defined( 'ABSPATH' ) || exit ;

/**
 * Get WC search field
 * 
 * @param array $args
 * @param bool $echo
 * @return string echo search field
 */
function _vrn_search_field( $args = array(), $echo = true ) {
	$args = wp_parse_args( $args, array(
		'class'       => '',
		'id'          => '',
		'name'        => '',
		'type'        => '',
		'action'      => '',
		'title'       => '',
		'placeholder' => '',
		'css'         => 'width: 50%;',
		'multiple'    => true,
		'allow_clear' => true,
		'selected'    => true,
		'options'     => array(),
			) ) ;

	ob_start() ;
	?>
	<select 
		id="<?php echo esc_attr( $args[ 'id' ] ) ; ?>" 
		class="<?php echo esc_attr( $args[ 'class' ] ) ; ?>" 
		name="<?php echo esc_attr( '' !== $args[ 'name' ] ? $args[ 'name' ] : $args[ 'id' ]  ) ; ?><?php echo ( $args[ 'multiple' ] ) ? '[]' : '' ; ?>" 
		data-action="<?php echo esc_attr( $args[ 'action' ] ) ; ?>" 
		data-placeholder="<?php echo esc_attr( $args[ 'placeholder' ] ) ; ?>" 
		<?php echo ( $args[ 'allow_clear' ] ) ? 'data-allow_clear="true"' : '' ; ?> 
		<?php echo ( $args[ 'multiple' ] ) ? 'multiple="multiple"' : '' ; ?> 
		style="<?php echo esc_attr( $args[ 'css' ] ) ; ?>">
			<?php
			if ( ! is_array( $args[ 'options' ] ) ) {
				$args[ 'options' ] = ( array ) $args[ 'options' ] ;
			}

			$args[ 'options' ] = array_filter( $args[ 'options' ] ) ;

			foreach ( $args[ 'options' ] as $id ) {
				$option_value = '' ;

				switch ( $args[ 'type' ] ) {
					case 'product':
						$product = wc_get_product( $id ) ;
						if ( $product ) {
							$option_value = wp_kses_post( $product->get_formatted_name() ) ;
						}
						break ;
					case 'customer':
						$user = get_user_by( 'id', $id ) ;
						if ( $user ) {
							$option_value = ( esc_html( $user->display_name ) . '(#' . absint( $user->ID ) . ' &ndash; ' . esc_html( $user->user_email ) . ')' ) ;
						}
						break ;
					default:
						$post = get_post( $id ) ;
						if ( $post ) {
							$option_value = sprintf( '(#%s) %s', $post->ID, wp_kses_post( $post->post_title ) ) ;
						}
						break ;
				}

				if ( $option_value ) {
					?>
				<option value="<?php echo esc_attr( $id ) ; ?>" <?php echo ( $args[ 'selected' ] ) ? 'selected="selected"' : '' ; ?>><?php echo esc_html( $option_value ) ; ?></option>
					<?php
				}
			}
			?>
	</select>
	<?php
	if ( $echo ) {
		ob_end_flush() ;
	} else {
		return ob_get_clean() ;
	}
}
