<?php

defined( 'ABSPATH' ) || exit;

/**
 * Handle enqueues.
 * 
 * @class VRN_Enqueues
 * @package Class
 */
class VRN_Enqueues {

	/**
	 * Init VRN_Enqueues.
	 */
	public static function init() {
		add_action( 'admin_enqueue_scripts', __CLASS__ . '::admin_script', 11 );
		add_action( 'admin_enqueue_scripts', __CLASS__ . '::admin_style', 11 );
		add_action( 'wp_enqueue_scripts', __CLASS__ . '::frontend_script' );
		add_action( 'wp_enqueue_scripts', __CLASS__ . '::frontend_style' );
	}

	/**
	 * Register and enqueue a script for use.
	 *
	 * @uses   wp_enqueue_script()
	 * @param  string   $handle
	 * @param  string   $path
	 * @param  array   $localize_data
	 * @param  string[] $deps
	 * @param  string   $version
	 * @param  boolean  $in_footer
	 */
	public static function enqueue_script( $handle, $path = '', $localize_data = array(), $deps = array( 'jquery' ), $version = VRN_VERSION, $in_footer = false ) {
		wp_register_script( $handle, $path, $deps, $version, $in_footer );

		$name = str_replace( '-', '_', $handle );
		wp_localize_script( $handle, "{$name}_params", $localize_data );
		wp_enqueue_script( $handle );
	}

	/**
	 * Register and enqueue a styles for use.
	 *
	 * @uses   wp_enqueue_style()
	 * @param  string   $handle
	 * @param  string   $path
	 * @param  string[] $deps
	 * @param  string   $version
	 * @param  string   $media
	 * @param  boolean  $has_rtl
	 */
	public static function enqueue_style( $handle, $path = '', $deps = array(), $version = VRN_VERSION, $media = 'all', $has_rtl = false ) {
		wp_register_style( $handle, $path, $deps, $version, $media, $has_rtl );
		wp_enqueue_style( $handle );
	}

	/**
	 * Return asset URL.
	 *
	 * @param string $path
	 * @return string
	 */
	public static function get_asset_url( $path ) {
		return VRN_URL . "/assets/{$path}";
	}

	/**
	 * Enqueue jQuery modal.
	 */
	public static function enqueue_jQuery_modal() {
		self::enqueue_script( 'jquery-modal', self::get_asset_url( 'js/jquery-modal/jquery.modal.min.js' ) );
		self::enqueue_style( 'jquery-modal', self::get_asset_url( 'js/jquery-modal/jquery.modal.min.css' ) );
	}

	/**
	 * Perform script localization in backend.
	 */
	public static function admin_script() {
		$screen    = get_current_screen();
		$screen_id = $screen ? $screen->id : '';

		//Admin Page.
		if ( isset( $_GET[ 'tab' ] ) && 'woocommerce_page_wc-settings' === $screen_id && 'vrn_variation_switcher_in_cart' === $_GET[ 'tab' ] ) {
			self::enqueue_script( 'vrn-admin', self::get_asset_url( 'js/admin/vrn-admin.js' ) );
		}
	}

	/**
	 * Load style in backend.
	 */
	public static function admin_style() {
	}

	/**
	 * Perform script localization in frontend.
	 */
	public static function frontend_script() {
		if ( _vrn()->is_enabled_for_users() || _vrn()->is_enabled_for_guests() ) {
			self::enqueue_jQuery_modal();
			self::enqueue_script( 'vrn-frontend', self::get_asset_url( 'js/frontend/vrn-frontend.js' ), array(
				'ajax_url'               => admin_url( 'admin-ajax.php' ),
				'switch_variation_nonce' => wp_create_nonce( 'vrn-switch-variation' ),
				'enabled_in_checkout'    => _vrn()->is_enabled_in_checkout(),
			) );
		}
	}

	/**
	 * Load style in frontend.
	 */
	public static function frontend_style() {
		if ( _vrn()->is_enabled_for_users() || _vrn()->is_enabled_for_guests() ) {
			self::enqueue_style( 'vrn-frontend-inline' );
			self::enqueue_style( 'vrn-frontend', self::get_asset_url( 'css/vrn-frontend.css' ) );

			$css = get_option( VRN_PREFIX . 'inline_style' );

			if ( '' !== $css ) {
				wp_add_inline_style( 'vrn-frontend-inline', $css );
			}
		}
	}
}

VRN_Enqueues::init();
