<?php

defined( 'ABSPATH' ) || exit;

/**
 * Installation related functions and actions.
 * 
 * @class VRN_Install
 * @package Class
 */
class VRN_Install {

	/**
	 * Init Install.
	 */
	public static function init() {
		add_action( 'init', array( __CLASS__, 'check_version' ), 9 );
		add_filter( 'plugin_action_links_' . VRN_BASENAME, array( __CLASS__, 'plugin_action_links' ) );
	}

	/**
	 * Check VRN version and run updater
	 */
	public static function check_version() {
		if ( get_option( VRN_PREFIX . 'version' ) !== VRN_VERSION ) {
			self::install();

			/**
			 * Trigger after plugin is updated.
			 * 
			 * @since 1.0
			 */
			do_action( 'vrn_updated' );
		}
	}

	/**
	 * Install WC CS.
	 */
	public static function install() {
		if ( ! defined( 'VRN_INSTALLING' ) ) {
			define( 'VRN_INSTALLING', true );
		}

		self::update_vrn_version();

		/**
		 * Trigger after plugin is installed.
		 * 
		 * @since 1.0
		 */
		do_action( 'vrn_installed' );
	}

	/**
	 * Is this a brand new VRN install?
	 * A brand new install has no version yet.
	 *
	 * @return bool
	 */
	private static function is_new_install() {
		return is_null( get_option( VRN_PREFIX . 'version', null ) );
	}

	/**
	 * Update VRN version to current.
	 */
	private static function update_vrn_version() {
		delete_option( VRN_PREFIX . 'version' );
		add_option( VRN_PREFIX . 'version', VRN_VERSION );
	}

	/**
	 * Show action links on the plugin screen.
	 *
	 * @param   mixed $links Plugin Action links
	 * @return  array
	 */
	public static function plugin_action_links( $links ) {
		$setting_page_link = '<a  href="' . admin_url( 'admin.php?page=wc-settings&tab=vrn_variation_switcher_in_cart' ) . '">' . esc_html__( 'Settings', 'variation-switcher-in-cart-for-woocommerce' ) . '</a>';
		array_unshift( $links, $setting_page_link );
		return $links;
	}
}

VRN_Install::init();
