<?php
defined( 'ABSPATH' ) || exit;

/**
 * Privacy/GDPR related functionality which ties into WordPress functionality.
 * 
 * @class VRN_Privacy
 * @package Class
 */
class VRN_Privacy {

	/**
	 * Init VRN_Privacy.
	 */
	public static function init() {
		add_action( 'admin_init', __CLASS__ . '::add_privacy_message' );
	}

	/**
	 * Get plugin name
	 * 
	 * @return string
	 */
	public static function get_plugin_name() {
		$plugin = get_plugin_data( VRN_FILE );
		return $plugin[ 'Name' ];
	}

	/**
	 * Adds the privacy message on WC Credits privacy page.
	 */
	public static function add_privacy_message() {
		if ( function_exists( 'wp_add_privacy_policy_content' ) ) {
			$content = self::get_privacy_message();

			if ( $content ) {
				wp_add_privacy_policy_content( self::get_plugin_name(), $content );
			}
		}
	}

	/**
	 * Add privacy policy content for the privacy policy page.
	 */
	public static function get_privacy_message() {
		ob_start();
		?>
		<p><?php esc_html_e( 'This includes the basics of what personal data your store may be collecting, storing and sharing. Depending on what settings are enabled and which additional plugins are used, the specific information shared by your store will vary.', 'variation-switcher-in-cart-for-woocommerce' ); ?></p>
		<h2><?php esc_html_e( 'WHAT DOES THE PLUGIN DO?', 'variation-switcher-in-cart-for-woocommerce' ); ?></h2>
		<p><?php esc_html_e( 'Variation Switcher in Cart for WooCommerce allows your users to change their variations on their cart page.', 'variation-switcher-in-cart-for-woocommerce' ); ?></p>
		<h2><?php esc_html_e( 'WHAT WE COLLECT AND STORE?', 'variation-switcher-in-cart-for-woocommerce' ); ?></h2>
		<h2><?php esc_html_e( 'This plugin does not collect or store any personal information about the users.', 'variation-switcher-in-cart-for-woocommerce' ); ?></h2>
		<?php
		/**
		 * Get plugin privacy policy content.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'vrn_privacy_policy_content', ob_get_clean() );
	}
}

VRN_Privacy::init();
