<?php

defined( 'ABSPATH' ) || exit ;

/**
 * Get Product category list
 *
 * @return array
 */
function _vrn_get_category_list() {
	$categorylist   = array() ;
	$listcategories = get_terms( 'product_cat' ) ;

	if ( is_array( $listcategories ) ) {
		foreach ( $listcategories as $category ) {
			$categorylist[ $category->term_id ] = $category->name ;
		}
	}

	return $categorylist ;
}

/**
 * Check the Variable Product is eligible to Switch.
 * 
 * @param int $product_id
 * @return boolean
 */
function _vrn_is_switchable( $product_id ) {
	$eligible = false ;

	switch ( get_option( VRN_PREFIX . 'get_product_select_type', 'all_products' ) ) {
		case 'all-products':
			$eligible = true ;
			break ;
		case 'included-products':
			if ( in_array( $product_id, get_option( VRN_PREFIX . 'get_included_products', array() ) ) ) {
				$eligible = true ;
			}
			break ;
		case 'excluded-products':
			if ( ! in_array( $product_id, get_option( VRN_PREFIX . 'get_excluded_products', array() ) ) ) {
				$eligible = true ;
			}
			break ;
		case 'included-categories':
			$variable_product_ids = _vrn_get_variable_products_from_cart() ;

			if ( empty( $variable_product_ids ) ) {
				break ;
			}

			$products = new WP_Query( array(
				'post_type'      => array( 'product' ),
				'post_status'    => 'publish',
				'posts_per_page' => '-1',
				'fields'         => 'ids',
				'cache_results'  => false,
				'tax_query'      => array(
					'relation' => 'AND',
					array(
						'taxonomy' => 'product_cat',
						'field'    => 'term_id',
						'terms'    => array_map( 'absint', get_option( VRN_PREFIX . 'get_included_categories', array() ) ),
						'operator' => 'IN',
					),
					array(
						'taxonomy' => 'product_type',
						'field'    => 'slug',
						'terms'    => _vrn()->supported_product_types(),
						'operator' => 'IN',
					),
				),
					) ) ;

			$found_products = ! empty( $products->posts ) ? $products->posts : array() ;

			if ( in_array( $product_id, array_intersect( $variable_product_ids, $found_products ) ) ) {
				$eligible = true ;
			}
			break ;
		case 'excluded-categories':
			$variable_product_ids = _vrn_get_variable_products_from_cart() ;

			if ( empty( $variable_product_ids ) ) {
				break ;
			}

			$products = new WP_Query( array(
				'post_type'      => 'product',
				'post_status'    => 'publish',
				'posts_per_page' => '-1',
				'fields'         => 'ids',
				'cache_results'  => false,
				'tax_query'      => array(
					'relation' => 'AND',
					array(
						'taxonomy' => 'product_cat',
						'field'    => 'term_id',
						'terms'    => array_map( 'absint', get_option( VRN_PREFIX . 'get_excluded_categories', array() ) ),
						'operator' => 'IN',
					),
					array(
						'taxonomy' => 'product_type',
						'field'    => 'slug',
						'terms'    => _vrn()->supported_product_types(),
						'operator' => 'IN',
					),
				),
					) ) ;

			$found_products = ! empty( $products->posts ) ? $products->posts : array() ;

			if ( ! in_array( $product_id, array_intersect( $variable_product_ids, $found_products ) ) ) {
				$eligible = true ;
			}
			break ;
	}

	return $eligible ;
}

/**
 * Return the Variable Product id(s) from Cart.
 * 
 * @return array
 */
function _vrn_get_variable_products_from_cart() {
	$variable_product_ids = array() ;

	if ( is_null( WC()->cart ) || empty( WC()->cart->cart_contents ) ) {
		return $variable_product_ids ;
	}

	foreach ( WC()->cart->cart_contents as $item ) {
		$product = wc_get_product( $item[ 'product_id' ] ) ;

		if ( ! $product ) {
			continue ;
		}

		if ( ! in_array( $product->get_type(), _vrn()->supported_product_types() ) ) {
			continue ;
		}

		$variable_product_ids[] = $item[ 'product_id' ] ;
	}

	return $variable_product_ids ;
}
