<?php
/**
 * Variable Product Form.
 *
 * This template can be overridden by copying it to yourtheme/variation-switcher-in-cart-for-woocommerce/variable.php.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$attribute_keys  = array_keys( $attributes );
$variations_json = wp_json_encode( $available_variations );

/**
 * Before variable form.
 * 
 * @since 1.6
 */
do_action( 'vrn_before_variable_form', $product, $available_variations, $cart_item_key );
?>
<div class="vrn-variable-form variations_form cart" id="cart_<?php echo esc_attr( $cart_item_key ); ?>" data-product_id="<?php echo absint( $product->get_id() ); ?>" data-product_variations="<?php echo wc_esc_json( $variations_json ); ?>">
	<?php if ( empty( $available_variations ) && false !== $available_variations ) : ?>
		<p class="stock out-of-stock">
		<?php
			/**
			 * Get out of stock message.
			 * 
			 * @since 1.0
			 */
			echo esc_html( apply_filters( 'vrn_out_of_stock_message', __( 'This product is currently out of stock and unavailable.', 'variation-switcher-in-cart-for-woocommerce' ) ) );
		?>
		</p>
	<?php else : ?>
		<p class="variations">
			<?php foreach ( $attributes as $attribute_name => $options ) : ?>
				<label for="<?php echo esc_attr( sanitize_title( $attribute_name ) ); ?>"><?php echo wp_kses_post( wc_attribute_label( $attribute_name ) ); ?></label>
				<?php
				wc_dropdown_variation_attribute_options(
						array(
							'options'   => $options,
							'attribute' => $attribute_name,
							'product'   => $product,
						)
				);

				/**
				 * Get reset variation link.
				 * 
				 * @since 1.0
				 */
				echo end( $attribute_keys ) === $attribute_name ? wp_kses_post( apply_filters( 'vrn_reset_variations_link', '<a class="reset_variations" href="#">' . esc_html__( 'Clear', 'variation-switcher-in-cart-for-woocommerce' ) . '</a>' ) ) : '';
				?>
			<?php endforeach; ?>
		</p>

		<div class="single_variation">
			<script type="text/template" id="tmpl-variation-template">
				<div class="woocommerce-variation-description">{{{ data.variation.variation_description }}}</div>
				<div class="woocommerce-variation-price">{{{ data.variation.price_html }}}</div>
				<div class="woocommerce-variation-availability">{{{ data.variation.availability_html }}}</div>
			</script>
		</div>

		<button class="vrn_switch_variation single_add_to_cart_button"><?php esc_html_e( get_option( VRN_PREFIX . 'update_variation_label' ) ); ?></button>
	<?php endif; ?>

	<div class="woocommerce-variation-add-to-cart">
		<input type="hidden" name="product_id" class="product_id" value="<?php echo absint( $product->get_id() ); ?>" />
		<input type="hidden" name="variation_id" class="variation_id" value="0" />
		<input type="hidden" name="vrn_cart_item_key" class="vrn_cart_item_key" value="<?php echo esc_html( $cart_item_key ); ?>" />
	</div>
</div>
<?php
/**
 * After variable form.
 * 
 * @since 1.6
 */
do_action( 'vrn_after_variable_form', $product, $available_variations, $cart_item_key );
